Attribute VB_Name = "PrimerMacros"
Public myName As String, myComp As String, myIn As Integer
Option Explicit
'The macros in this module are based on samples in the text of Chapter 23 of _
"Documents, Presentations, and Workbooks" for Office 2010 and Office for Mac 2011.
'Note that this module contains many, but not all of the code sample shown in _
that chapter.
' A couple of additional samples are included that combine concepts from the chapter.
'For additional examples of how to employ the concepts demonstrated in that chapter, _
see the file Sample Macros.dotm, available in the same Chapter23 sample files folder from which _
you accessed this module.

Sub FirstRecording()
    
    Selection.Style = ActiveDocument.Styles("Heading 1")
    Selection.TypeText Text:="Company Overview"
    Selection.TypeParagraph
    Selection.TypeParagraph
    Selection.TypeParagraph
    Selection.TypeParagraph

End Sub

Sub DataStoreSample()

SaveSetting "NorthwindTraders", "BrandPrefs", "Department", "Marketing"
SaveSetting "NorthwindTraders", "BrandPrefs", "Title", "Marketing Manager"
SaveSetting "NorthwindTraders", "BrandPrefs", "Location", "London"
SaveSetting "NorthwindTraders", "BrandPrefs", "Paper Size", "A4"
SaveSetting "NorthwindTraders", "BrandPrefs", "LetterStyle", "Personal Letterhead"

End Sub
Sub GroupingSample()

With Selection
    .Style = ActiveDocument.Styles("Heading 1")
    .TypeText "Company Overview-" & vbCr & vbCr & vbCr & vbCr
End With

End Sub

Sub GroupingSample2()

'Keep in mind that if you run this macro in a document that doesn't contain tables, _
has a table with less than 4 columns, or doesn't contain a paragraph styles named "Table heading" _
and "Table text," the macro will result in an error

With ActiveDocument.Tables(1)
    .Style = "Table Contemporary"
    .Range.Style = "Table text"
    .Columns(4).Shading.ForegroundPatternColor = wdColorLavender
    .Rows(1).Range.Style = "Table heading"
    .Rows(1).HeadingFormat = True
End With

End Sub


Sub GroupingSample3()

'nested With...End With structures

With ActiveDocument.Tables(1)
   .Style = "Table Contemporary"
   .Range.Style = "Table text"
   .Columns(4).Shading.ForegroundPatternColor = wdColorLavender
   With .Rows(1)
         .Range.Style = "Table heading"
         .HeadingFormat = True
   End With
End With

End Sub

Sub GroupingSample4()

'further nesting

With ActiveDocument.Tables(1)
   .Style = "Table Contemporary"
   .Range.Style = "Table text"
   With .Columns(4)
         .Shading.ForegroundPatternColor = wdColorLavender
         .Select
   End With
   Selection.Style = "Table Subheading"
   With .Rows(1)
         .Range.Style = "Table heading"
         .HeadingFormat = True
   End With
End With

End Sub

Sub LoopSample1()

'For Each...Next loop sample

Dim atb As Table

For Each atb In ActiveDocument.Tables
    atb.Style = "Table Contemporary"
Next atb

End Sub

Sub LoopSample2()

'For Each...Next sample 2

Dim ast As Style

For Each ast In ActiveDocument.Styles
    ast.Delete
Next ast

End Sub



Sub LoopSample3()

'For...Next sample

Dim myI As Integer

For myI = 6 To ActiveDocument.Tables.Count
    ActiveDocument.Tables(myI).Style = "Table Contemporary"
Next

End Sub



Sub LoopSample4()

'For...Next loop with nested With..End With structures

Dim myI As Integer

With ActiveDocument
    For myI = 6 To .Tables.Count
        With .Tables(myI)
            .Style = "Table Contemporary"
            .AutoFitBehavior (wdAutoFitWindow)
        End With
    Next myI
End With

End Sub


Sub LoopSample5()

'A top evalution Do Until...Loop structure

With ActiveDocument
    Do Until .Shapes.Count = 0
        .Shapes(1).Delete
    Loop
End With

End Sub


Sub LoopSample6()

'As noted in Chapter 21, although this macro works just fine, the Do While...Loop structure _
used here isn't the most efficient approach. This macro would be a bit simpler using a _
For...Next loop, as you see in the Sub LoopSample7 that follows.

Dim myI As Integer
myI = 6

With ActiveDocument
    Do While myI <= .Tables.Count
        With .Tables(myI)
            .Style = "Table Contemporary"
            .AutoFitBehavior (wdAutoFitWindow)
        End With
        myI = myI + 1
    Loop
End With

End Sub

Sub LoopSample7()

Dim myI As Integer

With ActiveDocument
    For myI = 6 To .Tables.Count
        With .Tables(myI)
            .Style = "Table Contemporary"
            .AutoFitBehavior (wdAutoFitWindow)
        End With
    Next myI
End With


End Sub


Sub LoopInSpecificStories()

Dim asc As Section
Dim hft As HeaderFooter

For Each asc In ActiveDocument.Sections
    For Each hft In asc.Headers
        hft.Range.Style = "Heading 1"
    Next hft
Next asc

End Sub

Sub IfThenSample()

Dim myPage As Integer

With Selection
    .EndKey (wdStory)
    myPage = .Information(wdActiveEndPageNumber)
End With

If myPage > 3 Then
    ActiveDocument.PageSetup.Orientation = wdOrientLandscape
End If

End Sub

Sub IfThenSample2()

Dim ast As Style

For Each ast In ActiveDocument.Styles
    If ast.BuiltIn = False Then
        ast.Delete
    End If
Next ast

End Sub

Sub IfThenElseSample()

Dim myPage As Integer

With Selection
    .EndKey (wdStory)
    myPage = .Information(wdActiveEndPageNumber)
End With

With ActiveDocument.PageSetup
    If myPage > 3 Then
        .Orientation = wdOrientLandscape
    Else
        .Orientation = wdOrientPortrait
    End If
End With

End Sub


Sub IfThenElseIfElseSample()

Dim atb As Table

For Each atb In ActiveDocument.Tables
    With atb
        If .Columns.Count = 4 Then
            .Style = "Table Financial 4"
        ElseIf .Columns.Count = 6 Then
            .Style = "Table Financial 6"
        Else
            .Style = "Table Normal"
        End If
    End With
Next atb

End Sub

Sub SelectCaseExample()

Dim atb As Table
For Each atb In ActiveDocument.Tables
   With atb
         Select Case .Columns.Count
            Case 4
               .Style = "Table Financial 4"
            Case 6
               .Style = "Table Financial 6"
            Case Else
               .Style = "Table Normal"
         End Select
   End With
Next atb

End Sub

Sub CombineLoopandSelectCaseExample()

Dim myI As Integer
myI = 1
With ActiveDocument
    For myI = 1 To .Paragraphs.Count
        With .Paragraphs(myI)
            Select Case .Style
                Case "Body Text", "Body Text 2", "Body Text 3"
                    .Style = "Normal"
                Case "Body Heading", "Document Heading", "Page Heading"
                    .Style = "Heading 1"
            End Select
        End With
    Next
End With

End Sub
Sub CombineLoopAndIfStatementExample()

Dim myI As Integer
myI = 1
With ActiveDocument
    For myI = 1 To .Paragraphs.Count
        With .Paragraphs(myI)
            If .Style = "Body Text" Or .Style = "Body Text 2" Or .Style = "Body Text 3" Then
                    .Style = "Normal"
             ElseIf .Style = "Body Heading" Or .Style = "Document Heading" Or _
                .Style = "Page Heading" Then
                    .Style = "Heading 1"
            End If
        End With
    Next
End With

End Sub
Sub OperatorSample1()

Dim apr As Paragraph

For Each apr In ActiveDocument.Paragraphs
    If apr.Style <> "Heading 1" And apr.Style <> "Heading 2" Then
        apr.Range.Delete
    End If
Next apr

End Sub

Sub OperatorSample2()

Dim apr As Paragraph

For Each apr In ActiveDocument.Paragraphs
    If apr.Style = "Heading 1" Or apr.Style = "Heading 2" Then
        apr.Range.Delete
    End If
Next apr

End Sub

Sub OperatorSample3()

Dim apr As Paragraph
    For Each apr In ActiveDocument.Paragraphs
        If (apr.Style = "Heading 1" Or apr.Style = "Heading 2") And _
            apr.Range.Information(wdWithInTable) = False Then
            apr.Range.Delete
        End If
Next apr

End Sub

Sub MessageBoxSample()

Dim myRes As Integer

'in the first instance that follows, MsgBox is being used as a function, because it _
returns a result
myRes = MsgBox("Are you an unstoppable VBA genius?", vbQuestion + vbYesNo, "My Message Box")

If myRes = vbYes Then
    'the two instances of MsgBox that follow are statements - they execute an action, but _
    don't return information
    MsgBox "I knew it!", vbExclamation, "My Message Box"
Else
    MsgBox "Hang in there.", vbCritical, "My Message Box"
End If

End Sub

Sub InputBoxSample()

Dim myInp As String

myInp = InputBox("How would you score on a basic VBA exam?", "My Input Box", "Perfect")

MsgBox myInp & " is pretty good!", vbExclamation, "My Input Box"

End Sub

Sub InputBox2()

Dim myInp As Integer

myInp = InputBox("How many columns would you like?", "My Input Box")

With Selection
    .Tables.Add Range:=.Range, NumRows:=5, NumColumns:=myInp
End With

End Sub

Private Sub VarDefs()

'macro to store variables used by other macros

myName = Application.UserName
myComp = ActiveDocument.BuiltInDocumentProperties("Company").Value
myIn = 1

End Sub


Sub CallVariableSample()

Call VarDefs

'Notice that, even though the procedure storing variable values was called - I can still _
assign a new value to one of those variables, if I only want to use the value passed of _
some variables passed from the procedure. In this case, I use the values of the two string _
variables passed from the procedure named VarDefs, but can set my own value for the integer _
value without causing a conflict

With ActiveDocument
    For myIn = 5 To .Tables.Count
        .Tables(myIn).Cell(1, 1).Range.Text = myName & ", " & myComp
    Next myIn
End With

End Sub


Sub EndAndExitSample()

'this macro combines an example of using an End statement and an Exit For statement

If Documents.Count = 0 Then
    End
End If

Dim ast As Style

For Each ast In ActiveDocument.Styles
    If ast.NameLocal = "Sample" Then
        ast.Delete
        Exit For
    End If
Next

End Sub


Sub CallMacroandExitSub()

'this macro calls the private sub FormatTable (which follows) to demonstrate the Exit Sub statement used _
in that procedure

Call VarDefs
Dim myRes As Integer

With ActiveDocument
    .Sections(1).Headers(wdHeaderFooterPrimary).Range.Text = myName & ", " & myComp
    
    myRes = MsgBox("Is this document an interoffice memo?", vbQuestion + vbYesNo, "DPW Primer Samples")
    If myRes = vbYes Then
        Call FormatTable
    End If
    'notice that the following statement refers to the last paragraph in the document
    'The Format function is used in the following statement to insert the date in the _
    format specified. In this case, the specified date format is the system long date specified _
    in Windows Regional & Language Settings
    .Paragraphs(.Paragraphs.Count).Range.Text = "Sent from the New York Office on " & Format(Date, "Long Date")
        

End With

End Sub


Private Sub FormatTable()

'using Exit Sub in this macro enables the previous procedure (CallMacroAndExitSub) to _
continue to run without error if no tables exist in the document. If I used End instead _
of Exit Sub, all code execution would end, so CallMacroAndExitSub would not continue to run.

With ActiveDocument
    If .Tables.Count = 0 Then
        Exit Sub
    End If
    With .Tables(1)
        .Style = "Light Shading - Accent 1"
        .Rows(1).Range.Style = "Heading 3"
    End With
End With

End Sub


Sub SelectCaseErrorHandlerSample()

Dim myInp As Integer

ResumeInputBox:

On Error GoTo ErrorHandler

myInp = InputBox("How many columns would you like?", "My Input Box")

With Selection
    .Tables.Add Range:=.Range, NumRows:=5, NumColumns:=myInp
End With

End

ErrorHandler:
Select Case Err.Number
    Case 13
        MsgBox "Please enter a numeric value to continue.", vbInformation
        Resume ResumeInputBox
    Case Else
        MsgBox Err.Description
End Select

End Sub
